using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using PhoenixDLL.Class;

namespace PhoenixDLL.GUI
{
    /// <summary>
    /// Frame des options du calendrier
    /// </summary>
    public partial class fr_Options : Form
    {
        #region Variables
        /// <summary>
        /// Objet de proprits
        /// </summary>
        protected Options options = Options.GetInstance();
        /// <summary>
        /// Copy of the options
        /// </summary>
        private SavedOptions vSavedOptions = new SavedOptions();
        #endregion

        #region Constructeurs
        /// <summary>
        /// Constructeur
        /// </summary>
        public fr_Options()
        {
            InitializeComponent();
            pg_Properties.SelectedObject = options;
            Options.Instance.RestartNeeded += new OnRestardNeededHandler(Event_RestartNeeded);
        }
        #endregion

        #region Event
        /// <summary>
        /// Evnement sur un clique sur OK
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_OK(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.OK;
            this.Close();
        }
        /// <summary>
        /// Evnement sur un clique sur Annuler
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_Cancel(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.Cancel;
            vSavedOptions.Undo();
            this.Close();
        }
        /// <summary>
        /// Restart needed because an option wants it
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Event_RestartNeeded(object sender, EventArgs e)
        {
            SavedOptions sopt = new SavedOptions();
            DialogResult dr = MessageBox.Show("Il faut redmarrer l'application! "
                + "\r\nVoulez-vous appliquer les changements et redmarrer?(RECOMMANDER)", "Question",
                MessageBoxButtons.YesNo, MessageBoxIcon.Question);
            if (dr == DialogResult.No) sopt.Undo();
            else if (dr == DialogResult.Yes)
            {
                Options.Instance.IsFirstInstance = true;
                Application.Restart();
            }
        }
        #endregion

        #region Messages
        /// <summary>
        /// Catch the message to see if the "closing cross" was clicked
        /// </summary>
        /// <param name="m"></param>
        protected override void WndProc(ref Message m)
        {
            if (m.Msg == 0x112 && (int)m.WParam == 0xF060)
                vSavedOptions.Undo();
            base.WndProc(ref m);
        }
        #endregion

        #region Properties
        /// <summary>
        /// Gets the PropertyGrid
        /// </summary>
        public PropertyGrid PropertyGrid { get { return this.pg_Properties; } }
        #endregion
    }
}